==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Autenticação expirou</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>O disco está ocupado, não pode ser desmontado agora</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>O disco está ocupado, não pode ser ejectado agora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>O dispositivo está ocupado, não é possível ejectar agora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>O dispositivo está ocupado, não é possível remover agora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>O dispositivo não foi removido com segurança</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clique em &quot;Remover com segurança&quot; e retire-o da próxima vez</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">O dispositivo está ocupado, não é possível ejectar agora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">O dispositivo está ocupado, não é possível remover agora</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Não é possível desmontar o dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>O disco foi montado pelo utilizador &quot;%1&quot;, não o pode desmontar.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Não é possível localizar o dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Ejectar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>O dispositivo foi removido com segurança</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acesso negado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Não tem autorização para aceder a esta pasta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>A analisar o dispositivo, interromper?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.9.2.orig.tar.xz: dde-file-manager-5.9.2/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Autenticação expirou</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>O disco está ocupado, não pode ser desmontado agora</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>O disco está ocupado, não pode ser ejectado agora</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>O dispositivo está ocupado, não é possível ejectar agora</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>O dispositivo está ocupado, não é possível remover agora</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>O dispositivo não foi removido em segurança</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Clique em &quot;Remover em segurança&quot; e retire-o da próxima vez</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Não é possível desmontar o dispositivo</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>O disco foi montado pelo utilizador &quot;%1&quot;, não o pode desmontar.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Não é possível localizar o dispositivo montado</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disco</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Ejectar tudo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>O dispositivo foi removido com segurança</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Acesso negado</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Não tem autorização para aceder a esta pasta</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>A analisar o dispositivo, interromper?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Confirmar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Parar</translation>
    </message>
</context>
</TS>
